@@ -1,7 +1,3 @@
-"""Much of this comes from https://github.com/algorand/auction-demo/blob/main/auction/util.py,
-
-"""
-
 import base64
 import logging
 from functools import cached_property
@@ -138,14 +134,8 @@ def get_kmd_client(settings: gw_config.VanillaSettings) -> KMDClient:
 
 class BasicAccount:
     """Representation of the public and private information of an Algorand
-    account, with extra documentation.
-
-    sk - the private signing key of the account
-    addr - the public address of the account. Essentially the public
-    key, massaged to reduce human error
-
-    generated by passing the private key. If none is passed
-    it will generate a new one
+    account, with a few shorthands on top of algosdk.account - in particular
+    x = BasicAccount() will generate a new BasicAccount.
     """
 
     def __init__(self, private_key: Optional[str] = None) -> None:
@@ -156,42 +146,25 @@ class BasicAccount:
 
     @cached_property
     def sk(self) -> str:
-        """The private signing key for the account.. Equivalent in information content
-        to the mnemonic. Evidentily should be kept private. Can generate the address and
-        the public key."""
+        """Shorthand for the account's private key"""
         return self._sk
 
     @cached_property
     def addr(self) -> str:
-        """A string in AlgoAddressStringFormat"""
+        """Shorthand property for the account's public key"""
         return self._addr
 
     def address(self) -> str:
-        """Returns an AlgoAddressStringFormat"""
+        """A method returning the account's public key. Equivalent to self.addr"""
         return self._addr
 
     def private_key(self) -> str:
-        """Returns the private signing key for the account.. Equivalent in information content
-        to the mnemonic. Evidentily should be kept private. Can generate the address and
-        the public key."""
+        """A method returning the account's private key. Equivalent to self.sk"""
         return self._sk
 
-    @cached_property
-    def public_key_as_string(self) -> str:
-        """For reasons that include the need to make the keys human-readable and robust
-        to human error when transferred, both the public and private keys undergo
-        transformation. The public key is transformed into an Algorand address,
-        by adding a 4-byte checksum to the end of the public key and then encoding it
-        in base32. The result is what both the developer and end-user recognize as an
-        Algorand address. The address is 58 characters long.
-
-        See the docs: https://developer.algorand.org/docs/get-details/accounts/
-        """
-        return address_to_public_key(self.addr)
-
     @cached_property
     def address_as_bytes(self) -> bytes:
-        """Also called public_key in algosdk"""
+        """Useful if digging into encoding and decoding between strings and bytes."""
         return bytes(encoding.decode_address(self.addr))
 
     @cached_property
@@ -204,21 +177,13 @@ class BasicAccount:
     @cached_property
     def addr_short_hand(self) -> str:
         """Returns the last 6 characters of the account address.
-
-        This is just used for logging messages and human eyes!
+        Used for logging messages and human eyes.
         """
         return self.addr[-6:]
 
     @classmethod
     def from_mnemonic(cls, m: str) -> "BasicAccount":
-        """Takes the string of 25 words (the mnemonic) and returns the BasicAccount
-
-        Args:
-            m (str): the mnemonic
-
-        Returns:
-            BasicAccount: the Algorand BasicAccount
-        """
+        """Takes the string of 25 words (the mnemonic) and returns the BasicAccount"""
         return cls(mnemonic.to_private_key(m))
 
     def __eq__(self, other: Any) -> bool:
@@ -315,6 +280,8 @@ class MultisigAccount:
 
 
 class PendingTxnResponse:
+    """Parses the dict object of a transaction response into a python class"""
+
     def __init__(self, tx_id: str, response: Dict[str, Any]) -> None:
         self.tx_id = tx_id
         self.pool_error: str = response["pool-error"]
@@ -345,6 +312,8 @@ class PendingTxnResponse:
 def wait_for_transaction(
     client: AlgodClient, tx_id: str, timeout: int = 10
 ) -> PendingTxnResponse:
+    """Translates algosdk client.pending_transaction_info into a python class
+    object PendingTxnResponse after waiting for a confirmed transaction"""
     lastStatus = client.status()
     lastRound = lastStatus["last-round"]
     startRound = lastRound
@@ -368,13 +337,10 @@ def wait_for_transaction(
 def send_signed_mtx(
     client: AlgodClient, mtx: MultisigTransaction
 ) -> PendingTxnResponse:
-    """Sends a signed transaction and returns
-    Args:
-        client (AlgodClient): _description_
-        mtx (MultisigTransaction): _description_
-
-    Returns:
-        int: _description_
+    """
+    Combines sending a Multisig transaction (sing send_raw_transaction)
+    with waiting for the transaction to complete, returning a python
+    PendingTxnResponse class object with the response.
     """
     txid = client.send_raw_transaction(encoding.msgpack_encode(mtx))
     LOGGER.info(f"Sent mtx w txid {txid[-6:]}. Waiting for confirmation")
@@ -384,7 +350,9 @@ def send_signed_mtx(
 def pay_account(
     client: AlgodClient, sender: BasicAccount, to_addr: str, amt_in_micros: int
 ) -> PendingTxnResponse:
-    """Sends algos from one account to another
+    """
+    Sends algos from one account to another.
+
     Args:
         client: AlgodClient
         sender: algo_utils.BasicAccount (not algo_utils.MultisigAccount)
@@ -430,6 +398,17 @@ def pay_account(
 
 
 def get_balances(client: AlgodClient, addr: str) -> Dict[int, int]:
+    """
+    Returns a dictionary of Algorand Standard Asset holdings
+
+    Args:
+        addr (str): public address holding the ASAs
+
+    Returns:
+       A dictionary taking the ids of the held ASAs to the amounts
+       of those ASAs held by the address.
+
+    """
     balances: Dict[int, int] = dict()
     try:
         property_format.check_is_algo_address_string_format(addr)
@@ -464,7 +443,7 @@ def micro_algos(addr: str) -> Optional[int]:
 
     Returns:
         Optional[int]: Return the number of microAlgos in an account, or None
-    if there is an issue getting this number
+        if there is an issue getting this number
     """
     property_format.check_is_algo_address_string_format(addr)
     settings = gw_config.VanillaSettings(_env_file=dotenv.find_dotenv())
@@ -481,11 +460,12 @@ def micro_algos(addr: str) -> Optional[int]:
 
 def algos(addr: str) -> Optional[float]:
     """
-    Args: acct (AlgoAccount): can also be a multiSig
+    Args:
+      acct (AlgoAccount): can also be a multiSig
 
     Returns:
         Optional[int]: Return the number of microAlgos in an account, or None
-    if there is an issue getting this number
+        if there is an issue getting this number
     """
     property_format.check_is_algo_address_string_format(addr)
     settings = gw_config.VanillaSettings(_env_file=dotenv.find_dotenv())
@@ -500,11 +480,21 @@ def algos(addr: str) -> Optional[float]:
     return round(microAlgoBalance / 10**6, 2)
 
 
-def verify_account_exists_and_funded(addr: str) -> bool:
-    """Raises an exception if an address is not a valid format, or
-    if the account does not have at least 1 Algo
-        Note that
-    every account on Algorand must have a minimum balance of 100,000 microAlgos."""
+def verify_account_exists_and_funded(addr: str) -> None:
+    """
+    Raises an exception if an address is not a valid format, or
+    if the account does not have at least 1 Algo. Note that
+    every account on Algorand must have a minimum balance of
+    100,000 microAlgos and this minimum balance increases with
+    more holdings.
+
+    Args:
+        addr(str): the Algorand public address in question
+
+    Raises:
+        errors.AlgoError: if addr does not have AlgoAddressStringFormat, or does not have at least 1 Algo.
+
+    """
     try:
         property_format.check_is_algo_address_string_format(addr)
     except:
@@ -523,5 +513,3 @@ def verify_account_exists_and_funded(addr: str) -> bool:
             f"Insufficient funds for account ..{addr[-6:]}. Need 1 Algo"
             f" and only have {algoBalance}"
         )
-
-    return True
